makeMultivalueCyllinder<-function(
  ### Function to create a list of points on the
  ### cyllinder around DNA helix in the positions identical to 
  ### generated by our Coulomb calculations. File ofile could be used
  ### with APBS data as follow:
  ###      multivalue test.csv result.dx test.surf.out
  ### and test.surf.out could be analysed with makePhi2D function.
  zMin,##<< Position of the first circule of cyllinder
  zMax,##<< Position of the last circule of cyllinder
  radius=15,##<< Radius of the cyllinder
  ofile##<< path to file to write
){
   z<-floor(zMin):ceiling(zMax)
   a<-pi*(0:359)/180
   points<-matrix(nrow=length(z)*length(a),ncol=3)
   k<-1
   for (i in z) {
      for (j in a) {
         points[k,1]<-radius*cos(j)
         points[k,2]<-radius*sin(j)
         points[k,3]<-i
         k<-k+1
       }
    }
    
    write.table(points,file=ofile,sep=',',,row.names=FALSE,col.names=FALSE)
    
}

makePhi2D<-function(
  ### Function to convert results of APBS multivalue function into
  ### 2D matrix for further analysis.
  file##<< input file, result of multivalue invocation.
){
   pot<-read.table(file,header=FALSE,sep=',')
   names(pot)<-c('X','Y','Z','phi')
   pot$alpha<-atan2(pot$X,pot$Y)
   pot$alphaG<-pot$alpha*180/pi
   pot$alphaG<-round(pot$alpha*180/pi)
   factor(pot$Z)->pot$Zlev
   pot$Zind<-as.integer(pot$Zlev)
   factor(pot$alphaG)->pot$alphaLev
   pot$alphaInd<-as.integer(pot$alphaLev)
   phi<-matrix(pot$phi, nrow=max(pot$alphaInd), ncol=max(pot$Zind), byrow=FALSE, dimnames=list(levels(pot$alphaLev),levels(pot$Zlev)))
   ##value<< matrix with angle in rows and Z in columns
   return(phi)
}
